package WebGUI::i18n::German::Asset_EventManagementSystem;
use utf8;
our $I18N = {
  'Admin manage sub events large resultset' => {
    'lastUpdated' => '1251858808',
    'message' => 'Sie können die folgenden Veranstaltungen verwalten. Da zu viele Unter-Veranstaltungen vorhanden sind, können nicht alle Veranstaltungen dargestellt werden. Bitte grenzen Sie die Ergebnisse durch die weiter oben aufgeführten Filteroptionen ein. '
  },
  'Admin manage sub events small resultset' => {
    'lastUpdated' => '1240697624',
    'message' => 'Sie können die folgenden Veranstaltungen verwalten. Sie k&ouml;nnen die Ergebnisse durch die weiter oben aufgeführten Filteroptionen eingrenzen. '
  },
  'Event Number' => {
    'lastUpdated' => '1240697656',
    'message' => 'Veranstaltungsnummer'
  },
  'None' => {
    'lastUpdated' => '1180436978',
    'message' => 'Keine'
  },
  'Pagination variables' => {
    'lastUpdated' => '1180437029',
    'message' => 'Allgemeine Seitenaufteilung Template Variablen.'
  },
  'Unlink User' => {
    'lastUpdated' => '1180437040',
    'message' => 'Unlink Benutzer'
  },
  'User sub events large resultset' => {
    'lastUpdated' => '1240697691',
    'message' => 'Sie können auch aus den folgenden Unter-Veranstaltungen wählen. Auf Grund der vielen Unter-Veranstaltungen k&ouml;nnen nicht alle dargestellt werden. Bitte grenzen Sie die Ergebnisse durch die weiter oben aufgeführten Filteroptionen ein. '
  },
  'User sub events small resultset' => {
    'lastUpdated' => '1240697712',
    'message' => 'Sie können auch aus den folgenden Unter-Veranstaltungen wählen. Sie k&ouml;nnen die Ergebnisse durch die weiter oben aufgeführten Filteroptionen eingrenzen. '
  },
  'add a badge' => {
    'lastUpdated' => '1239657601',
    'message' => 'Namensschild hinzufügen'
  },
  'add a badge group' => {
    'lastUpdated' => '1239657633',
    'message' => 'Namensschild-Gruppe hinzufügen'
  },
  'add a ribbon' => {
    'lastUpdated' => '1239657664',
    'message' => 'Rabattschein hinzufügen'
  },
  'add a ticket' => {
    'lastUpdated' => '1239657926',
    'message' => 'Eintrittskarte hinzufügen'
  },
  'add a token' => {
    'lastUpdated' => '1239658305',
    'message' => 'Gutschein hinzufügen'
  },
  'add an event meta field' => {
    'lastUpdated' => '1241171158',
    'message' => 'Ein Meta-Feld hinzufügen'
  },
  'add discount pass' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'add event' => {
    'lastUpdated' => '1180437201',
    'message' => 'Termin hinzufügen'
  },
  'add more items' => {
    'lastUpdated' => '1238534610',
    'message' => 'Weitere Items hinzufügen'
  },
  'add new event metadata field' => {
    'lastUpdated' => '1180437219',
    'message' => 'Neues Termin Metadaten Feld hinzufügen'
  },
  'add prerequisite set' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'add registrant' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'add submission' => {
    'lastUpdated' => '1258546921',
    'message' => 'Neu'
  },
  'add to badge' => {
    'lastUpdated' => '1239657971',
    'message' => 'Zum Namensschild hinzugügen'
  },
  'add to badge message' => {
    'lastUpdated' => '1239657701',
    'message' => '%s wurde erfolgreich zu Ihrem Namneschild hinzugefügt'
  },
  'add to cart' => {
    'lastUpdated' => '1238534663',
    'message' => 'Zum Einkaufskorb hinzufügen'
  },
  'add/edit approve event' => {
    'lastUpdated' => '1240697737',
    'message' => 'Veranstaltung bestätigen'
  },
  'add/edit event add another prerequisite' => {
    'lastUpdated' => '1199975297',
    'message' => 'Füge eine andere Voraussetzung hinzu'
  },
  'add/edit event assigned prerequisites' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'add/edit event description' => {
    'lastUpdated' => '1199975329',
    'message' => 'Beschreibung'
  },
  'add/edit event description description' => {
    'lastUpdated' => '1240697802',
    'message' => 'Details der Veranstaltung z.B. Ort, Zeit und Thema.'
  },
  'add/edit event end date' => {
    'lastUpdated' => '1199975388',
    'message' => 'Enddatum Termin'
  },
  'add/edit event end date description' => {
    'lastUpdated' => '1199975412',
    'message' => 'Zeit und Datum, an dem der Termin endet.'
  },
  'add/edit event error' => {
    'lastUpdated' => '1199975419',
    'message' => 'FEHLER'
  },
  'add/edit event image' => {
    'lastUpdated' => '1241171206',
    'message' => 'Veranstaltungsbild'
  },
  'add/edit event image description' => {
    'lastUpdated' => '1241171318',
    'message' => 'Ein Bild, das die Veranstaltung repräsentiert. Angezeigt für Seitenbesucher. '
  },
  'add/edit event maximum attendees' => {
    'lastUpdated' => '1199975457',
    'message' => 'Maximale Anzahl Teilnehmer'
  },
  'add/edit event maximum attendees description' => {
    'lastUpdated' => '1199975508',
    'message' => 'Die Anzahl der maximalen Teilnehmer, abgeleitet von Raumgrösse, Personal und anderer Faktoren.'
  },
  'add/edit event metadata field' => {
    'lastUpdated' => '1199975532',
    'message' => 'Hinzufügen/Editieren Termin Metadaten Feld'
  },
  'add/edit event operator' => {
    'lastUpdated' => '1238534844',
    'message' => 'Verantwortlicher'
  },
  'add/edit event operator description' => {
    'lastUpdated' => '1251834322',
    'message' => 'Wenn vorausgesetzte Veranstaltungen zu dieser Veranstaltung hinzugefügt werden, können Sie angeben, ob alle (UND) dieser Veranstaltungen oder eine (ODER) dieser Veranstaltungen vorausgesetzt wird.'
  },
  'add/edit event price description' => {
    'lastUpdated' => '1199975564',
    'message' => 'Teilnahmekosten.'
  },
  'add/edit event required events' => {
    'lastUpdated' => '1240697754',
    'message' => 'Vorausgesetzte Veranstaltungen'
  },
  'add/edit event required events description' => {
    'lastUpdated' => '1251834483',
    'message' => 'Sie können voraussetzen, dass der Nutzer für bestimmte Veranstaltungen registriert ist, bevor er sich für diese Veranstaltung registrieren kann.'
  },
  'add/edit event return to manage events' => {
    'lastUpdated' => '1199975639',
    'message' => 'Zur Verwaltung der Termine zurückkehren'
  },
  'add/edit event start date' => {
    'lastUpdated' => '1199975663',
    'message' => 'Termin Startdatum'
  },
  'add/edit event start date description' => {
    'lastUpdated' => '1199975684',
    'message' => 'Zeit und Datum des Terminbeginns.'
  },
  'add/edit event start date help' => {
    'lastUpdated' => '1251834512',
    'message' => 'Zeit und Datum des Veranstaltungsbeginns '
  },
  'add/edit event template' => {
    'lastUpdated' => '1199975693',
    'message' => 'Termin Template'
  },
  'add/edit event template description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'add/edit event title' => {
    'lastUpdated' => '1199975706',
    'message' => 'Termin Titel'
  },
  'add/edit event title description' => {
    'lastUpdated' => '1240697772',
    'message' => 'Geben Sie den Namen oder den Titel der Veranstaltung ein.'
  },
  'add/edit event what next' => {
    'lastUpdated' => '1199975744',
    'message' => 'Was kommt als nächstes?'
  },
  'add/edit event what next description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'add/edit useSalesTax' => {
    'lastUpdated' => '1238534924',
    'message' => 'Steuerpflichtig?'
  },
  'add/edit useSalesTax description' => {
    'lastUpdated' => '1239657760',
    'message' => 'Ist diese Veranstaltung MwSt.-pflichtig?'
  },
  'addBadgeUrl' => {
    'lastUpdated' => '1251834585',
    'message' => 'URL zum Hinzufügen eines Namensschilds'
  },
  'addEvent.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'addEvent.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'addRibbonUrl' => {
    'lastUpdated' => '1251834610',
    'message' => 'URL um dem Namensschild ein Band hinzuzufügen'
  },
  'addTicketUrl' => {
    'lastUpdated' => '1251834698',
    'message' => 'URL um dem Namensschild ein Ticket hinzuzufügen.'
  },
  'addToBadgeMessage' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'addTokenUrl' => {
    'lastUpdated' => '1239658361',
    'message' => 'Die URL um dem Namensschild einen Gutschein zuzuordnen.'
  },
  'address' => {
    'lastUpdated' => '1217254760',
    'message' => 'Adresse'
  },
  'address1' => {
    'lastUpdated' => '1239657341',
    'message' => 'Adresszeile 1 des Namensschilds'
  },
  'address2' => {
    'lastUpdated' => '1239657368',
    'message' => 'Adresszeile 2 des Namensschilds'
  },
  'address3' => {
    'lastUpdated' => '1239658002',
    'message' => 'Adresszeile 3 des Namensschilds'
  },
  'addressBook' => {
    'lastUpdated' => '1239657476',
    'message' => 'Ein Knopf zum Abruf einer Adresse aus dem Adressbuch des Benutzers'
  },
  'advSearch.formHeader' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'all' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'allowed sub events' => {
    'lastUpdated' => '1251834856',
    'message' => 'Sie können die folgenden Unterveranstaltungen auf Grund der Veranstaltungen in Ihrem Einkaufswagen besuchen.'
  },
  'amount off' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'and' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'any' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'appUrl' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'approval' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'approve event' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'approve event description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'approved' => {
    'lastUpdated' => '1258546934',
    'message' => 'Überprüft'
  },
  'assetId' => {
    'lastUpdated' => '1257325908',
    'message' => 'Asset-ID des Tickets'
  },
  'assetName' => {
    'lastUpdated' => '1251834870',
    'message' => 'Veranstaltungsplaner'
  },
  'assetSize' => {
    'lastUpdated' => '1257325928',
    'message' => 'Größe dieses Asset-Tickets'
  },
  'assigned discount pass' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'assigned discount pass description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'assigned prerequisite set' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'assigned prerequisite set description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'associated user' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'associated user description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'auto search' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'auto search description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'badge builder template' => {
    'lastUpdated' => '1251834899',
    'message' => 'Namensschildbilder Template'
  },
  'badge builder template help' => {
    'lastUpdated' => '1240697538',
    'message' => 'Welche Vorlage möchten Sie für die Erstellung der Namensschilder verwenden?'
  },
  'badge group name' => {
    'lastUpdated' => '1251834923',
    'message' => 'Namensschildgruppenname'
  },
  'badge group name help' => {
    'lastUpdated' => '1251835073',
    'message' => 'Diese Bezeichnung bezieht sich auf alle Namensschilder in dieser Gruppe zusammen.'
  },
  'badge group ticketsPerBadge' => {
    'lastUpdated' => '1309239056',
    'message' => 'Tickets pro Namensschild'
  },
  'badge group ticketsPerBadge help' => {
    'lastUpdated' => '1309239108',
    'message' => 'Die Anzahl an Tickets, die zu jedem Namensschild in dieser Gruppe erworben werden dürfen.'
  },
  'badge groups' => {
    'lastUpdated' => '1251835092',
    'message' => 'Namensschilderguppe'
  },
  'badge holder information' => {
    'lastUpdated' => '1251835119',
    'message' => 'Namensschildinhaberinformation'
  },
  'badge id' => {
    'lastUpdated' => '1251835138',
    'message' => 'Namensschild-ID'
  },
  'badge instructions' => {
    'lastUpdated' => '1251835150',
    'message' => 'Namensschildanweisungen'
  },
  'badge instructions help' => {
    'lastUpdated' => '1251835203',
    'message' => 'Dem Benutzer Hilfestellung dazu geben, was er mit dem Namensschild tun soll'
  },
  'badge number' => {
    'lastUpdated' => '1239658395',
    'message' => 'Namensschild-Nr.'
  },
  'badgeAssetId' => {
    'lastUpdated' => '1251835226',
    'message' => 'Die Asset-ID für dieses Namensschild'
  },
  'badgeBuilderTemplateId help' => {
    'lastUpdated' => '1251835267',
    'message' => 'Die ID für das Template der Namensschildbilderansicht'
  },
  'badgeId' => {
    'lastUpdated' => '1251835300',
    'message' => 'Die ID für das Namensschild des aktuellen Nutzers'
  },
  'badgeInstructions help' => {
    'lastUpdated' => '1251835345',
    'message' => 'Anweisungen für den Benutzer, was er mit dem Namensschild tun kann'
  },
  'badgeLabel' => {
    'lastUpdated' => '1251835504',
    'message' => 'Ein internationalisierter und personalisierter Bezeichner für das andere Namensschild im Einkaufswagen des Benutzers.'
  },
  'badgeNumber' => {
    'lastUpdated' => '1251835641',
    'message' => 'Die Nummer des Namensschildes'
  },
  'badgeTitle' => {
    'lastUpdated' => '1251835667',
    'message' => 'Der Titel des zu druckenden Namensschildes'
  },
  'badgeUrl' => {
    'lastUpdated' => '1251835756',
    'message' => 'Der URL um dem Warenkorb ein weiteres Namensschild hinzuzufügen'
  },
  'basicSearch.formHeader' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'buildBadgeUrl' => {
    'lastUpdated' => '1251835790',
    'message' => 'URL der Informationen zum aktuellen Namensschild anzeigt'
  },
  'buy' => {
    'lastUpdated' => '1239658018',
    'message' => 'Kaufen'
  },
  'buy badge' => {
    'lastUpdated' => '1251835807',
    'message' => 'Ein Namensschild kaufen'
  },
  'buyBadgeUrl' => {
    'lastUpdated' => '1251835891',
    'message' => 'URL, um ein Namensschild zu kaufen'
  },
  'calendarJS' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'canAddEvents' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'canEdit' => {
    'lastUpdated' => '1251835963',
    'message' => 'Eine Bedingungen die anzeigt, ob der aktuelle Benutzer das Veranstaltungsmanagementsystem bearbeiten darf'
  },
  'canManageEvents' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'canReturn' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'canReturnItinerary' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'canReturnTransaction' => {
    'lastUpdated' => '1251836010',
    'message' => 'Ein boolscher Wert der anzeigt, ob ein Einkauf zurückgegeben werden kann.'
  },
  'cancel registration' => {
    'lastUpdated' => '1251836140',
    'message' => 'Registrierung abbrechen'
  },
  'check required fields' => {
    'lastUpdated' => '1251836161',
    'message' => 'Sie haben diese Pflichtfelder nicht angegeben:'
  },
  'checked in' => {
    'lastUpdated' => '1251836172',
    'message' => 'Angemeldet'
  },
  'checkout' => {
    'lastUpdated' => '1251836183',
    'message' => 'Abgemeldet'
  },
  'checkout template' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'checkout template description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'checkout template help title' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'checkout.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'checkout.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'choose a file to import' => {
    'lastUpdated' => '1248388655',
    'message' => 'Zu importierende Datei auswählen'
  },
  'city' => {
    'lastUpdated' => '1238534949',
    'message' => 'Ort'
  },
  'clear form' => {
    'lastUpdated' => '1314565706',
    'message' => 'Löschen'
  },
  'confirm delete event' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'confirm delete event metadata' => {
    'lastUpdated' => '1251836276',
    'message' => 'Sind Sie sicher, dass Sie dieses Metadatenfeld löschen möchten? Die Metadaten dieses Feldes werden von allen Veranstaltungen gelöscht.'
  },
  'confirm delete prerequisite' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'confirm delete prerequisite set' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'confirm delete purchase' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'continue' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'continue.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'continue.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'country' => {
    'lastUpdated' => '1248388628',
    'message' => 'Land'
  },
  'create a badge for myself' => {
    'lastUpdated' => '1251836304',
    'message' => 'Ein Namensschild für mich selbst erstellen'
  },
  'create a badge for someone else' => {
    'lastUpdated' => '1251836329',
    'message' => 'Ein Namensschild für jemand anders erstellen'
  },
  'create new user' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'created' => {
    'lastUpdated' => '1258546944',
    'message' => 'Erstellt'
  },
  'created by' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'created by description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'createdByUserId' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'creationDate' => {
    'lastUpdated' => '1257325964',
    'message' => 'Datum in Epoch-Notation an dem das Asset erstellt wurde.'
  },
  'customRequestUrl' => {
    'lastUpdated' => '1251836379',
    'message' => 'URL für YUI um Informationen über das aktuelle Namensschild anzufordern.'
  },
  'datePurchasedHuman' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'default badge instructions' => {
    'lastUpdated' => '1251836504',
    'message' => 'Sie brauchen ein Namensschild um an diesem Kongress teilzunehmen. Wählen Sie ein Namensschild, das Ihren Anforderungen und ihrem Budget entspricht.'
  },
  'default ribbon instructions' => {
    'lastUpdated' => '1251836774',
    'message' => 'Bänder gewähren Rabatte auf eine Gruppe dazugehörender Veranstaltungen. Sie können Ihrem Namensschild ein oder mehrere Bänder hinzufügen, die auf dazugehörende Veranstaltungen  Rabatte gewähren.'
  },
  'default submitted location list' => {
    'lastUpdated' => '1258915460',
    'message' => 'Der Standardwert für die Ortsliste der Veranstaltungen'
  },
  'default ticket instructions' => {
    'lastUpdated' => '1251836909',
    'message' => 'Ein Ticket ermöglicht eine Platzreservierung für eine Veranstaltung auf einem Kongress. Fügen Sie ihrem Namensschild ein Ticket für jede Veranstaltung hinzu, an der Sie teilnehmen möchten. '
  },
  'default token instructions' => {
    'lastUpdated' => '1251837086',
    'message' => 'Gutscheine sind eine Kongresswährung. Damit können Sie Veranstaltungen und andere Dinge erwerben, ohne ein Ticket kaufen zu müssen.'
  },
  'defines discount pass' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'delete' => {
    'lastUpdated' => '1239658028',
    'message' => 'Löschen'
  },
  'denied' => {
    'lastUpdated' => '1258547432',
    'message' => 'Abgelehnt'
  },
  'description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'discount amount' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'discount amount description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'discount pass id' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'discount pass id description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'discount pass member' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'discount pass type' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'discount pass type description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'display template' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'display template description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'duration' => {
    'lastUpdated' => '1239658406',
    'message' => 'Dauer'
  },
  'duration help' => {
    'lastUpdated' => '1251837109',
    'message' => 'Wie lange dauert diese Veranstaltung?'
  },
  'early bird price' => {
    'lastUpdated' => '1251837121',
    'message' => 'Frühbucherpreis'
  },
  'early bird price end date' => {
    'lastUpdated' => '1251837144',
    'message' => 'Frühbucherpreis-Enddatum'
  },
  'early bird price end date help' => {
    'lastUpdated' => '1251837176',
    'message' => 'Das Datum, an dem der Frühbucherpreis durch den vollen Preis ersetzt wird.'
  },
  'early bird price help' => {
    'lastUpdated' => '1251837208',
    'message' => 'Der Spezialpreis dieses Namensschildes, wenn der Nutzer früh bestellt.'
  },
  'edit' => {
    'lastUpdated' => '1248388672',
    'message' => 'Bearbeiten'
  },
  'edit discount pass' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'edit prerequisite set' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'edit registrant' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'edit submission form' => {
    'lastUpdated' => '1258546992',
    'message' => 'Bearbeiten Neuer Beitrag'
  },
  'email' => {
    'lastUpdated' => '1251837239',
    'message' => 'Die E-Mailadresse des Namensschildnutzers.'
  },
  'email address' => {
    'lastUpdated' => '1248388966',
    'message' => 'E-Mail-Adresse'
  },
  'ems asset template variables' => {
    'lastUpdated' => '1251837288',
    'message' => 'Templatevariablen des Veranstaltungsplaner-Assets'
  },
  'ems badge' => {
    'lastUpdated' => '1251837350',
    'message' => 'Veranstaltungsplaner Namensschild'
  },
  'ems ribbon' => {
    'lastUpdated' => '1251837372',
    'message' => 'Veranstaltungsplaner-Band'
  },
  'ems ticket' => {
    'lastUpdated' => '1251837385',
    'message' => 'Veranstaltungsplaner-Ticket'
  },
  'ems token' => {
    'lastUpdated' => '1251837404',
    'message' => 'Veranstaltungsplaner-Gutschein'
  },
  'ems view badge address1' => {
    'lastUpdated' => '1251837888',
    'message' => 'Formular für das erste Adressfeld im Template der Veranstaltungsplaner-Namensschild-Ansicht'
  },
  'ems view badge address2' => {
    'lastUpdated' => '1251837880',
    'message' => 'Formular für das zweite Adressfeld im Template der Veranstaltungsplaner-Namensschild-Ansicht'
  },
  'ems view badge address3' => {
    'lastUpdated' => '1251837873',
    'message' => 'Formular für das dritte Adressfeld im Template der Veranstaltungsplaner-Namensschild-Ansicht'
  },
  'ems view badge city' => {
    'lastUpdated' => '1251837865',
    'message' => 'Formular für das Stadtfeld im Template der Veranstaltungsplaner-Namensschild-Ansicht'
  },
  'ems view badge country' => {
    'lastUpdated' => '1251837857',
    'message' => 'Formular für das Landfeld im Template der Veranstaltungsplaner-Namensschild-Ansicht'
  },
  'ems view badge description' => {
    'lastUpdated' => '1251837680',
    'message' => 'Beschreibung für das Namensschild '
  },
  'ems view badge email' => {
    'lastUpdated' => '1251837841',
    'message' => 'Formular für das E-Mail-Feld im Template der Veranstaltungsplaner-Namensschild-Ansicht'
  },
  'ems view badge error' => {
    'lastUpdated' => '1251837748',
    'message' => 'Fehlermeldungen des Versuchs, dieses Namensschild in den Einkaufswagen zu legen.'
  },
  'ems view badge name' => {
    'lastUpdated' => '1251837829',
    'message' => 'Formular für das Benutzernamensfeld im Template der Veranstaltungsplaner-Namensschild-Ansicht'
  },
  'ems view badge organization' => {
    'lastUpdated' => '1251837806',
    'message' => 'Formular für das Feld Benutzerorganisation im Template der Veranstaltungsplaner-Namensschild-Ansicht'
  },
  'ems view badge phone' => {
    'lastUpdated' => '1251837905',
    'message' => 'Formular für das Telefonfeld im Template der Veranstaltungsplaner-Namensschild-Ansicht'
  },
  'ems view badge state' => {
    'lastUpdated' => '1251837923',
    'message' => 'Formular für das Feld Staat im Template der Veranstaltungsplaner-Namensschild-Ansicht'
  },
  'ems view badge submitAddress' => {
    'lastUpdated' => '1251837942',
    'message' => 'Button, um die Adressdaten abzuschicken'
  },
  'ems view badge title' => {
    'lastUpdated' => '1251837975',
    'message' => 'Der Titel des Namensschildes'
  },
  'ems view badge zipcode' => {
    'lastUpdated' => '1251837999',
    'message' => 'Formular für das PLZ-Feld im Template der Veranstaltungsplaner-Namensschild-Ansicht'
  },
  'ems.wobject.dir' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'emsAssetId' => {
    'lastUpdated' => '1251838045',
    'message' => 'Die Asset-ID für das Veranstaltungsmanagementsystem, das das Namensschild enthält'
  },
  'encryptPage' => {
    'lastUpdated' => '1257326001',
    'message' => 'Soll die Seite, auf der das Ticket angezeigt wird, verschlüsselt werden?'
  },
  'endDate' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'endDate.human' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'endDateHuman' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'ends' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'ends.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'enter import file' => {
    'lastUpdated' => '1251838072',
    'message' => 'Geben Sie eine Datei an, die importiert werden soll.'
  },
  'error' => {
    'lastUpdated' => '1239658038',
    'message' => 'Fehler'
  },
  'error badge group ticket limit' => {
    'lastUpdated' => '1309239272',
    'message' => 'Das Ticket-Limit ist erreicht, %s kann nicht hinzugefügt werden.'
  },
  'error no colon' => {
    'lastUpdated' => '1239658427',
    'message' => 'Fehler'
  },
  'event' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'event number' => {
    'lastUpdated' => '1251838087',
    'message' => 'Veranstaltungsnummer'
  },
  'event number help' => {
    'lastUpdated' => '1251838146',
    'message' => 'Eine Nummer, die die Veranstaltung bezeichnet und auf die man sich leicht beziehen kann, z.B. in einem Veranstaltungskatalog'
  },
  'event start date' => {
    'lastUpdated' => '1251838158',
    'message' => 'Anfangsdatum'
  },
  'event submission main template' => {
    'lastUpdated' => '1258547486',
    'message' => 'Hauptvorlage neue Veranstaltung'
  },
  'event submission main template help' => {
    'lastUpdated' => '1259618445',
    'message' => 'Diese Vorlage wird verwendet für die Hauptseite zur Definition einer Veranstaltung. 
Es gibt dynamisches Menüs, die ein oder mehrere Teile der Veranstaltungsschnittschnelle enthalten '
  },
  'event submission queue template' => {
    'lastUpdated' => '1259618510',
    'message' => 'Vorlage Veranstaltungsreihe'
  },
  'event submission queue template help' => {
    'lastUpdated' => '1259618797',
    'message' => 'Dies ist die Vorlage zur Anzeige der Vernatsaltungsreihe und wird vom Beitragenden und von Adminsitrator verwendet.'
  },
  'event submission template' => {
    'lastUpdated' => '1259618530',
    'message' => 'Vorlage Veranstaltung'
  },
  'event submission template help' => {
    'lastUpdated' => '1259618708',
    'message' => 'Diese Vorlage wird verwendet für die Eingabe einer Veranstaltung. Der Inhalt wird zusammengestellt auf Basis der Beschreibung des Adminsitrators, der diesen Beitrag eingegeben hat.'
  },
  'event template help title' => {
    'lastUpdated' => '1251843569',
    'message' => 'Veranstaltungsmanagementsystem Veranstaltungstemplate'
  },
  'eventIsApproved' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'eventIsFull' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'eventMetaData' => {
    'lastUpdated' => '1257326042',
    'message' => 'Metadaten des Events, Ausgabe erfolgt in JSON-Datenstruktur'
  },
  'events required by description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'events required by this prerequisite set' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'events_loop' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'expire ems cart items' => {
    'lastUpdated' => '1251843763',
    'message' => 'Ablauf des Einkaufswageninhaltes'
  },
  'export' => {
    'lastUpdated' => '1248389415',
    'message' => 'Exportieren'
  },
  'export error' => {
    'lastUpdated' => '1251843786',
    'message' => 'Es gab einen Fehler beim Export'
  },
  'export events' => {
    'lastUpdated' => '1251843798',
    'message' => 'Veranstaltungen exportieren'
  },
  'exportTicketsUrl' => {
    'lastUpdated' => '1251843840',
    'message' => 'URL zum Ticketexport. Zur Zeit nicht implementiert!'
  },
  'extraHeadTags' => {
    'lastUpdated' => '1257326080',
    'message' => 'Zusätzliche Tags die im Kopf dieses Tickets angezeigt werden sollen'
  },
  'extraHeadTagsPacked' => {
    'lastUpdated' => '1257633162',
    'message' => 'Zusätzliche Tags die im Kopf dieses Tickets angezeigt werden sollen, miminiert, ohne Whitespace'
  },
  'failed' => {
    'lastUpdated' => '1258547033',
    'message' => 'Fehler'
  },
  'feedback' => {
    'lastUpdated' => '1258547059',
    'message' => 'Feedback'
  },
  'field count mismatch' => {
    'lastUpdated' => '1251843915',
    'message' => 'Eintrag %d hat %d Felder und nicht %d wie durch die markierten Auswahlboxen angegeben. '
  },
  'filter' => {
    'lastUpdated' => '1251666405',
    'message' => 'Filter'
  },
  'first name' => {
    'lastUpdated' => '1248389006',
    'message' => 'Vorname'
  },
  'forced narrowing' => {
    'lastUpdated' => '1251843982',
    'message' => 'Wegen der vielen Voraussetzungen werden hier keine angezeigt. Bitte grenzen Sie die Auswahl mit den obigen Filtern ein.'
  },
  'formFooter' => {
    'lastUpdated' => '1251844044',
    'message' => 'Formularfuß für das Ansichtstemplate des Namensschildes'
  },
  'formHeader' => {
    'lastUpdated' => '1251844055',
    'message' => 'Formularkopf für das Ansichtstemplate des Namensschildes'
  },
  'getBadgesUrl' => {
    'lastUpdated' => '1251844104',
    'message' => 'URL um Namensschildinformationen im JSON Format an die YUI Datentabelle zu übergeben.'
  },
  'getRegistrantsUrl' => {
    'lastUpdated' => '1251844145',
    'message' => 'URL um Informationen zum Registrierten als JSON zu übergeben'
  },
  'getRibbonsUrl' => {
    'lastUpdated' => '1251844175',
    'message' => 'URL um Band-Informationen als JSON zu erhalten'
  },
  'getTicketsUrl' => {
    'lastUpdated' => '1251844196',
    'message' => 'URL um Ticketinformationen als JSON zu erhalten'
  },
  'getTokensUrl' => {
    'lastUpdated' => '1251844210',
    'message' => 'URL um Gutscheininformationen als JSON zu erhalten'
  },
  'global metadata' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'global metadata description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'global prerequisite' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'global prerequisite description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'group to add events' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'group to add events description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'group to approve events' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'group to approve events description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'groupIdEdit' => {
    'lastUpdated' => '1257326322',
    'message' => 'ID der Gruppe, die dieses Ticket bearbeiten darf'
  },
  'groupIdView' => {
    'lastUpdated' => '1257326346',
    'message' => 'ID der Gruppe die dieses Ticket betrachten darf'
  },
  'hasBadge' => {
    'lastUpdated' => '1251844243',
    'message' => 'Eine Bedingung die anzeigt, ob der aktuelle Nutzer ein Namensschild hat.'
  },
  'hasCheckedIn' => {
    'lastUpdated' => '1251844310',
    'message' => 'Eine Bedingungsvariable die wahr ist, wenn sich der Nutzer zur Veranstaltung eingeschrieben hat.'
  },
  'help badgeMeta' => {
    'lastUpdated' => '1309239446',
    'message' => 'Füge Metadaten-Werte zum Template hinzu indem der Name hinter "badgeMeta_" ergänzt wird. Beispiel: badgeMeta_department'
  },
  'help ticketMeta' => {
    'lastUpdated' => '1309239485',
    'message' => 'Füge Metadaten-Werte zum Template hinzu indem der Name hinter "ticketMeta_" ergänzt wird. Beispiel: ticketMeta_department'
  },
  'hours' => {
    'lastUpdated' => '1239658049',
    'message' => 'Stunden'
  },
  'ignore first line' => {
    'lastUpdated' => '1239658450',
    'message' => 'Erste Zeile ignorieren?'
  },
  'image' => {
    'lastUpdated' => '1251666425',
    'message' => 'Das Bild, das für diese Veranstaltung steht'
  },
  'import' => {
    'lastUpdated' => '1251666438',
    'message' => 'Importieren'
  },
  'import blank line' => {
    'lastUpdated' => '1251845272',
    'message' => 'Eintrag %d war leer (wurde übersprungen)'
  },
  'import events' => {
    'lastUpdated' => '1251845295',
    'message' => 'Veranstaltung importieren'
  },
  'import field is duplicate key description' => {
    'lastUpdated' => '1251853441',
    'message' => 'Um doppelte Datensätze auf intelligente Art und weise zu behandeln, muss das System einen Datensatz als Duplikat identifizieren. Durch Auswahl dieser Checkboxen teilen Sie dem System mit welche Felder es beachten soll, bei der Suche nach bereits existierenden Feldern für die Veranstaltung die importiert wird.
Wenn Sie beispielsweise Veranstaltungstitel und Veranstaltungsanfangsdatum als einzige Felder mit Doppelschlüsseln markieren und von den importieren Feldern  Veranstaltungstitel und Veranstaltungsanfangsdatum welche mit existierenden Feldern übereinstimmen, wird der importiere Datensatz als Duplikat behandelt. In diesem Fall wird er entweder verworfen oder der existierende Datensatz wird überschreiben.'
  },
  'import field is duplicate key title' => {
    'lastUpdated' => '1251845357',
    'message' => 'Feld ist doppelter Schlüssel'
  },
  'import file contains field description' => {
    'lastUpdated' => '1251853593',
    'message' => 'Markieren Sie die Checkboxen neben den Feldern, die in Ihrer Inputdatei enthalten sind. Beachten Sie, dass die Felder in der angezeigten Reihenfolge sein müssen und alle benötigten Felder markiert und ausgefüllt sein müssen für das Fortschreiben des Imports.'
  },
  'import file contains field title' => {
    'lastUpdated' => '1251852148',
    'message' => 'Datei enthält Feld'
  },
  'import form header' => {
    'lastUpdated' => '1251851942',
    'message' => 'Mit diesem Formular können Sie Daten direkt in das Veranstaltungsmanagementsystem importieren. Vergewissern Sie sich, dass Ihre Felder in der nachfolgenden Reihenfolge festgelegt sind. '
  },
  'import hoverhelp dups' => {
    'lastUpdated' => '1251853911',
    'message' => 'Das System wird die Felder zur Bestimmung von Duplikaten heranziehen, die Sie unter "Feld ist Dublettenschlüssel" angegeben haben. Wenn eine Dublette gefunden wurde, wird hier ausgewählt, das getan werden soll - importierten Datensatz verwerfen oder den alten Datensatz mit dem neuen überschreiben. Beachten Sie, dass alle Felder in überschriebenen Datensätzen auch überschrieben werden, unbeachtet, ob sie im importierten Datensatz vorhanden sind oder nicht.'
  },
  'import hoverhelp file' => {
    'lastUpdated' => '1251855053',
    'message' => 'Laden Sie eine Datei mit Komma-getrennten Werten (CSV) hoch (Tabellenkalkulationen können dieses Format ausgeben.) Die Felder müssen durch Kommata getrennt sein und Felder die ein Komma enthalten mit doppelten Anführungszeichen umschlossen sein. Enthaltene doppelte Anführungszeichen werden mit einem weiteren doppelte Anführungszeichen ("") maskiert. Ihre Datei wird auf die Feldanzahl und Pflichtfelder vor einem Import überprüft. Treten Fehler auf, werden Sie informiert und es findet keine Import statt. Diese Überprüfung schließt keine Gültigkeitsprüfung von LDAP, Datenbanklinks oder Templates ein. Das Format von Spezialfeldern ist das selbe, das auch beim Export verwandt wird. Wenn Sie eine Frage zur exakten Formatierung haben, untersuchen Sie eine Exportdatei und formatieren Ihre Inputdatei entsprechend. Listenfelder mit mehreren Werten sollten in einem CSV-Feld zusammengefasst und mit einem Strichpunk (;) getrennt werden.'
  },
  'import hoverhelp first line' => {
    'lastUpdated' => '1251855157',
    'message' => 'Enthält die erste Zeile Ihrer Importdatei Feldnamen statt Daten, wählen Sie ja, ansonsten nein.'
  },
  'import invalid prereq' => {
    'lastUpdated' => '1251855291',
    'message' => 'Datensatz %d enthält einen ungültigen Namenswert (%s) für einen Voraussetzungssatz. Sie müssen den Voraussetzungssatz vor dem Import erstellen.'
  },
  'import invalid status' => {
    'lastUpdated' => '1251855490',
    'message' => 'Datensatz %d hat einen ungültigen Statuswert (%s). Gültige Werte sind: Genehmigt, Abgebrochen, Versagt, Schwebend'
  },
  'import invalid template' => {
    'lastUpdated' => '1251855604',
    'message' => 'Datensatz %d enthält einen ungültigen Namenswert (%s) für ein Veranstaltungstempalte. Sie müssen das entsprechende Veranstaltungstemplate vor dem Import erstellen.'
  },
  'import line parse error' => {
    'lastUpdated' => '1251855682',
    'message' => 'Es trat ein Fehler bei der Verarbeitung der Eingab auf, \'%s\' in Zeile %d.'
  },
  'import missing required' => {
    'lastUpdated' => '1251855774',
    'message' => 'In Datensatz %d ist das Pflichtfeld %s nicht ausgefüllt.'
  },
  'import need dup key' => {
    'lastUpdated' => '1251850261',
    'message' => 'Sie müssen mindestens eine Doppelschlüssel-Auswahlbox markieren'
  },
  'import ok' => {
    'lastUpdated' => '1239658538',
    'message' => 'Alle %d Datensätze wurden erfolgreich importiert. %d neu angelegt, %d Leerzeilen, %d Doppeleinträge %s.'
  },
  'import other line' => {
    'lastUpdated' => '1251855820',
    'message' => 'Datensatz %d war %s'
  },
  'import record parse error' => {
    'lastUpdated' => '1251855867',
    'message' => 'Es trat ein Fehler bei der Verarbeitung des Datensatzes %d auf: \'%s\''
  },
  'importTicketsUrl' => {
    'lastUpdated' => '1251855893',
    'message' => 'URL für den Ticketimport. Zur Zeit nicht implementiert.'
  },
  'inheritUrlFromParent' => {
    'lastUpdated' => '1257326385',
    'message' => 'Soll die URL des Elternelements geerbt werden?'
  },
  'is required' => {
    'lastUpdated' => '1239658559',
    'message' => '%s ist erforderlich'
  },
  'isAdvSearch' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'isExportable' => {
    'lastUpdated' => '1257326399',
    'message' => 'Ist das Ticket exportierbar'
  },
  'isHidden' => {
    'lastUpdated' => '1257326426',
    'message' => 'Soll das Ticket aus dem Menü ausgeblendet werden?'
  },
  'isPackage' => {
    'lastUpdated' => '1257326444',
    'message' => 'Ist dieses Ticket-Asset ein Paket?'
  },
  'isPrototype' => {
    'lastUpdated' => '1257326457',
    'message' => 'Ist dieses Ticket-Asset ein Prototyp?'
  },
  'isRegistrationStaff' => {
    'lastUpdated' => '1251847078',
    'message' => 'Eine Bedingungsvariable die wahr ist, wenn der aktuelle Benutzer in der Gruppe für Registrierungspersonal für diese Veranstaltungsverwaltung ist.'
  },
  'item expiration time' => {
    'lastUpdated' => '1251855930',
    'message' => 'Verfallszeit'
  },
  'item expiration time help' => {
    'lastUpdated' => '1251856350',
    'message' => 'Wie lange sollen Dinge des Veranstaltungsmanagementsystems im Einkaufskorb reserviert bleiben, bevor die verfallen und wieder für den Verkauf freigegeben werden?'
  },
  'label' => {
    'lastUpdated' => '1251666466',
    'message' => 'Bezeichner'
  },
  'label help' => {
    'lastUpdated' => '1251856419',
    'message' => 'Der Bezeichner für das Feld, das der Benutzer lesen wird um zu wissen wofür das Feld ist.'
  },
  'last name' => {
    'lastUpdated' => '1251846946',
    'message' => 'Familienname'
  },
  'lastModified' => {
    'lastUpdated' => '1257326482',
    'message' => 'Datum in Epoch-Notation an dem das Ticket zuletzt geändert wurde'
  },
  'location' => {
    'lastUpdated' => '1239658070',
    'message' => 'Veranstaltungsort'
  },
  'location help' => {
    'lastUpdated' => '1251666561',
    'message' => 'In welchem Raum oder welchem Ort findet diese Veranstaltung statt?'
  },
  'lookup badge' => {
    'lastUpdated' => '1251850290',
    'message' => 'Ein Namensschild suchen'
  },
  'lookup registrant template' => {
    'lastUpdated' => '1251856473',
    'message' => 'Registrantsuche Template'
  },
  'lookup registrant template help' => {
    'lastUpdated' => '1251856525',
    'message' => 'Welches Template möchten Sie für die Registrantsuche-Seite benutzen?'
  },
  'lookupRegistrantTemplateId help' => {
    'lastUpdated' => '1251856555',
    'message' => 'Template ID für die Registrantsuche-Seite'
  },
  'lookupRegistrantUrl' => {
    'lastUpdated' => '1251856672',
    'message' => 'URL um Informationen über die Namensschilder des aktuellen Nutzers zu bekommen, oder für alle Nutzer, wenn der aktuelle Nutzer zum Registrierungspersonal gehört.'
  },
  'main template' => {
    'lastUpdated' => '1251847117',
    'message' => 'Haupttemplate'
  },
  'main template help' => {
    'lastUpdated' => '1251847182',
    'message' => 'Welches Template möchten Sie für die Hauptseite verwenden, die die zu kaufenden Namensschilder auflistet?'
  },
  'main template help body' => {
    'lastUpdated' => '1251856796',
    'message' => 'Dieses Template benutzt YUI für den größten Teil der Ausgabearbeit. Bitte ändern Sie das CSS um Anzeige- oder Stil-Änderungen vorzunehmen.'
  },
  'main template help title' => {
    'lastUpdated' => '1251856833',
    'message' => 'Haupttemplate des Veranstaltungsmanagements'
  },
  'manage' => {
    'lastUpdated' => '1251850306',
    'message' => 'Bearbeiten'
  },
  'manage discount passes' => {
    'lastUpdated' => '1251856868',
    'message' => 'Rabattpässe verwalten'
  },
  'manage event metadata' => {
    'lastUpdated' => '1251856883',
    'message' => 'Veranstaltungsmetadaten verwalten'
  },
  'manage events' => {
    'lastUpdated' => '1251856901',
    'message' => 'Veranstaltungen verwalten'
  },
  'manage prerequisite sets' => {
    'lastUpdated' => '1251856932',
    'message' => 'Voraussetzungssätze bearbeiten'
  },
  'manage prerequisites' => {
    'lastUpdated' => '1251856962',
    'message' => 'Voraussetzungen für diese Veranstaltung bearbeiten'
  },
  'manage purchases' => {
    'lastUpdated' => '1251856977',
    'message' => 'Einkäufe bearbeiten'
  },
  'manage purchases template' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manage purchases template description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manage purchases template help title' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manage registrants' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manageBadgeGroupsUrl' => {
    'lastUpdated' => '1251857002',
    'message' => 'URL um eine Liste mit Namensschildgruppen anzuzeigen'
  },
  'manageEventMetaFieldsUrl' => {
    'lastUpdated' => '1251857037',
    'message' => 'URL zur Verwaltungsseite der Veranstaltungsmetadaten'
  },
  'manageEvents.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manageEvents.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'managePrereqsMessage' => {
    'lastUpdated' => '1251857113',
    'message' => 'Benutzen Sie das folgende Formular, um Voraussetzungszuweisungen hinzuzufügen zu %s.'
  },
  'managePurchases.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'managePurchases.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'managePurchasesTitle' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manageToolbar' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'mark as checked in' => {
    'lastUpdated' => '1251857131',
    'message' => 'Als eingeschrieben markieren'
  },
  'mark as not checked in' => {
    'lastUpdated' => '1251857154',
    'message' => 'Als nicht eingeschrieben markieren'
  },
  'maximumAttendees' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'menuTitle' => {
    'lastUpdated' => '1257326514',
    'message' => 'Der Titel des Tickets, der im Menü angezeigt werden soll'
  },
  'message' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'meta field help text' => {
    'lastUpdated' => '1259144977',
    'message' => 'Hilfetext'
  },
  'meta field help text description' => {
    'lastUpdated' => '1259620244',
    'message' => 'Dieser Text wird bei der Registrierung angezeigt.'
  },
  'meta fields' => {
    'lastUpdated' => '1251847197',
    'message' => 'Metafelder'
  },
  'meta hover help' => {
    'lastUpdated' => '1251847274',
    'message' => 'Dies ist ein Bedarfsfeld. Bitten Sie Ihren Administrator um Anweisungen.'
  },
  'missing prerequisites message' => {
    'lastUpdated' => '1251850450',
    'message' => 'Einige Veranstaltungen setzen voraus, dass Sie an einer anderen Veranstaltung teilgenommen haben. Bitte erfüllen Sie die Voraussetzungen der folgenden Liste.'
  },
  'my submissions' => {
    'lastUpdated' => '1259619670',
    'message' => 'Meine Registrierungen'
  },
  'name' => {
    'lastUpdated' => '1240697840',
    'message' => 'Benutzername zum Namensschilds'
  },
  'name.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'new form' => {
    'lastUpdated' => '1259619746',
    'message' => 'Neues Formular'
  },
  'new price' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'new submission' => {
    'lastUpdated' => '1259619781',
    'message' => 'Veranstaltung registrieren'
  },
  'new submission form' => {
    'lastUpdated' => '1259619832',
    'message' => 'Registrierungen verwalten'
  },
  'newWindow' => {
    'lastUpdated' => '1257326537',
    'message' => 'Soll dieses Ticket in einem neuen Fenster angezeigt werden?'
  },
  'next submission id label' => {
    'lastUpdated' => '1259619851',
    'message' => 'Nächte Registrierungs-ID'
  },
  'next submission id label help' => {
    'lastUpdated' => '1259619916',
    'message' => 'Dies ist der Wert, der der ersten Registrierung zugewiesen wird. 
Bitte nicht ändern!'
  },
  'no' => {
    'lastUpdated' => '1251667128',
    'message' => 'Nein'
  },
  'no import took place' => {
    'lastUpdated' => '1251850503',
    'message' => 'Es wurden keine Datensätze importiert. Es traten Fehler in der Eingabe auf:'
  },
  'no more available' => {
    'lastUpdated' => '1251850556',
    'message' => 'Fehler: Keine weiteren Dinge zu kaufen.'
  },
  'no sets to display' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'noSearchDialog' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'not checked in' => {
    'lastUpdated' => '1251850576',
    'message' => 'Nicht eingeschrieben'
  },
  'notes' => {
    'lastUpdated' => '1251850587',
    'message' => 'Anmerkungen'
  },
  'null field error' => {
    'lastUpdated' => '1251850610',
    'message' => 'Das Feld %s darf nicht leer bleiben.'
  },
  'null field error recnum' => {
    'lastUpdated' => '1251850644',
    'message' => 'Das Feld %s darf nicht leer bleiben (Datensatz %d).'
  },
  'numberOfSearchResults' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'numberRegistered' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'operator type' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'operator type description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'option to narrow' => {
    'lastUpdated' => '1251850734',
    'message' => 'Sie können die Liste angezeigter Voraussetzung durch das setzen von obigen Filteroptionen beschränken.'
  },
  'or' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'organization' => {
    'lastUpdated' => '1251847287',
    'message' => 'Organisation'
  },
  'otherBadgesInCart' => {
    'lastUpdated' => '1251850806',
    'message' => 'Eine Schleife, die Links und Labels für andere Namensschilder im Warenkorb des Nutzers enthält.'
  },
  'overwrite' => {
    'lastUpdated' => '1251666891',
    'message' => 'Überschreiben'
  },
  'overwritten' => {
    'lastUpdated' => '1251666903',
    'message' => 'überschrieben'
  },
  'ownerUserId' => {
    'lastUpdated' => '1257326556',
    'message' => 'Nutzer-ID des Ticket-Eigentümers'
  },
  'paginate after' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'paginate after description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'paginateBar' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'pass name' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'pass name description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'pending' => {
    'lastUpdated' => '1259145016',
    'message' => 'Wartend'
  },
  'percent off' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'percentage discount' => {
    'lastUpdated' => '1251666923',
    'message' => 'Prozentualer Rabatt'
  },
  'percentage discount help' => {
    'lastUpdated' => '1251847649',
    'message' => 'Welcher prozentuale Rabatt soll auf die Tickets gewährt werden, wenn der Nutzer dieses Band kauft?'
  },
  'phone number' => {
    'lastUpdated' => '1251666851',
    'message' => 'Telefonnummer'
  },
  'phoneNumber' => {
    'lastUpdated' => '1251847584',
    'message' => 'Telefonnummer des Namensschildnutzers'
  },
  'populate from address book' => {
    'lastUpdated' => '1251666878',
    'message' => 'Aus Adressbuch übernehmen'
  },
  'pre registration price' => {
    'lastUpdated' => '1251850938',
    'message' => 'Vorregistrierungspreis'
  },
  'pre registration price end date' => {
    'lastUpdated' => '1251850960',
    'message' => 'Vorregistrierungspreis Enddatum'
  },
  'pre registration price end date help' => {
    'lastUpdated' => '1251850913',
    'message' => 'Datum, an dem der Vorregistrierungspreis durch den Frühbucherpreis ersetzt wird.'
  },
  'pre registration price help' => {
    'lastUpdated' => '1251851037',
    'message' => 'Der Spezialpreis dieses Namensschildes, wenn der Nutzer besonders früh bestellt.'
  },
  'prereq set name field description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'prereq set name field label' => {
    'lastUpdated' => '1251851067',
    'message' => 'Voraussetzungssetname'
  },
  'price' => {
    'lastUpdated' => '1239658134',
    'message' => 'Bruttopreis'
  },
  'price help' => {
    'lastUpdated' => '1251847307',
    'message' => 'Der Bruttopreis dieses Namensschildes'
  },
  'price must be greater than zero' => {
    'lastUpdated' => '1251847357',
    'message' => 'Preis muss größer Null sein.'
  },
  'price.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'print' => {
    'lastUpdated' => '1248388723',
    'message' => 'Drucken'
  },
  'print badge template' => {
    'lastUpdated' => '1251851231',
    'message' => 'Druckvorlage Namensschild'
  },
  'print badge template help' => {
    'lastUpdated' => '1251851265',
    'message' => 'Welches Template möchten Sie für den Druck der Namensschilder nutzen?'
  },
  'print remaining ticket template' => {
    'lastUpdated' => '1257326583',
    'message' => 'Template für den Druck der restlichen Tickets'
  },
  'print remaining ticket template help' => {
    'lastUpdated' => '1257326614',
    'message' => 'EMS Template für den Druck der restlichen Tickets'
  },
  'print remaining tickets' => {
    'lastUpdated' => '1257326627',
    'message' => 'Restliche Tickets drucken'
  },
  'print ticket template' => {
    'lastUpdated' => '1251851288',
    'message' => 'Drucktempalte Tickets'
  },
  'print ticket template help' => {
    'lastUpdated' => '1251851321',
    'message' => 'Welches Tempalte möchten Sie für den Druck der Tickets nutzen?'
  },
  'printBadgeTemplateId help' => {
    'lastUpdated' => '1251851355',
    'message' => 'Die ID des Drucktemplates für Namensschilder'
  },
  'printRemainingTicketsUrl' => {
    'lastUpdated' => '1257326648',
    'message' => 'URL zur Seite für den Druck der restlichen Tickets'
  },
  'printTicketTemplateId help' => {
    'lastUpdated' => '1251851418',
    'message' => 'Die ID des Drucktemplates für Tickets'
  },
  'productId' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'purchase.label' => {
    'lastUpdated' => '1251851523',
    'message' => 'Der internationalisierte Bezeichner "Add to Cart". Ist die Veranstaltung ausgebucht ist diese Variable leer.'
  },
  'purchase.message' => {
    'lastUpdated' => '1251851597',
    'message' => 'Eine Meldung, um den Nutzer zu fragen, ob er Unterveranstaltungen für diese Veranstaltung sehen möchte. Ist die Veranstaltung ausgebucht, ist diese Variable leer.'
  },
  'purchase.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'purchase.wantToContinue.url' => {
    'lastUpdated' => '1251851655',
    'message' => 'URL um diese Veranstaltung in den Einkaufswagen zu legen. Ist die Veranstaltung ausgebucht, ist diese Variable leer.'
  },
  'purchase.wantToSearch.url' => {
    'lastUpdated' => '1251851716',
    'message' => 'URL um nach Veranstaltungen zu suchen, die Voraussetzung für diese Veranstaltung sind. Ist die Veranstaltung ausgebucht, ist diese Variable leer.'
  },
  'purchaseComplete' => {
    'lastUpdated' => '1251850172',
    'message' => 'Eine bedingte Variable die wahr ist, wenn der Einkauf des Namensschildes komplett ist.'
  },
  'purchaseUrl' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'purchasesLoop' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'quantity available' => {
    'lastUpdated' => '1251847717',
    'message' => '# verfügbar'
  },
  'refresh events list' => {
    'lastUpdated' => '1251850125',
    'message' => 'Veranstaltungsliste neu laden'
  },
  'refund' => {
    'lastUpdated' => '1251847371',
    'message' => 'Rückzahlung'
  },
  'regLoop' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'registration info message' => {
    'lastUpdated' => '1251859855',
    'message' => 'Geben Sie Namensschild/Kontaktinformationen für die Serie von Veranstaltungen ein, die Sie aktuell dem Einkaufskorb hinzufügen.

Wenn Sie angemeldet sind, können Sie für eine Aktualisierung die Informationen ihres eigenen Benutzerprofils auswählen, indem Sie Ihren Namen aus der Dropdown-Box auswählen, oder wenn Ihr Name nicht aufgeführt ist, wählen Sie die Option" Erstelle Namensschild für mich selbst"

Wenn Sie den Kauf für jemand anders durchführen, wählen Sie dessen Name oder wählen "Erstelle neues Namensschild für jemand anderen" aus der Dropdown-Auswahl. Wenn Sie etwas zu einem früheren Kauf hinzufügen möchten, ist das Namensschild bereits ausgewählt und kann nicht mehr geändert werden. Wenn Sie im Formular Änderungen an einem Feld für ein existierendes Namensschild vornehmen, werden die Informationen aktualisiert. 
'
  },
  'registration staff group' => {
    'lastUpdated' => '1251857816',
    'message' => 'Gruppe Registrierungspersonal'
  },
  'registration staff group help' => {
    'lastUpdated' => '1251857996',
    'message' => 'Wählen Sie eine Nutzergruppe, die Registrierungen verwaltet. Diese Nutzer können Namensschildregistrierungen von jedem Teilnehmer suchen und verwalten.'
  },
  'registrationId' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'registrationStaffGroupId help' => {
    'lastUpdated' => '1251857788',
    'message' => 'Die ID für die Gruppe, die Registrierungen bearbeitet.'
  },
  'related badge groups' => {
    'lastUpdated' => '1251857271',
    'message' => 'Zugeordnete Namensschildgruppen'
  },
  'related badge groups badge help' => {
    'lastUpdated' => '1251858264',
    'message' => 'Markieren Sie Namensschildgruppen, die zu diesem Namensschild gehören, so dass den Tickets Voraussetzungsnamensschilder zugewiesen werden können.'
  },
  'related badge groups ticket help' => {
    'lastUpdated' => '1251858334',
    'message' => 'Markieren Sie die Namensschildgruppen, die als Voraussetzung gelten, um diese Veranstaltung zu besuchen. Ist keine markiert, geht es mit allen.'
  },
  'related ribbons' => {
    'lastUpdated' => '1251857292',
    'message' => 'Zugeordnete Bänder'
  },
  'related ribbons help' => {
    'lastUpdated' => '1251857329',
    'message' => 'Prüfe die Bänder, die einen Rabatt für dieses Ticket gewähren können'
  },
  'relatedBadgeGroups' => {
    'lastUpdated' => '1257326750',
    'message' => 'Namensschild-Gruppen für dieses Ticket'
  },
  'relatedRibbons' => {
    'lastUpdated' => '1257326760',
    'message' => 'Bänder für dieses Ticket'
  },
  'remove' => {
    'lastUpdated' => '1239658146',
    'message' => 'Entfernen'
  },
  'reset user' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'returned' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'revisedBy' => {
    'lastUpdated' => '1257326798',
    'message' => 'ID des Nutzers, der das Ticket zuletzt geändert hat'
  },
  'revisionDate' => {
    'lastUpdated' => '1257326838',
    'message' => 'Datum in Epoch-Notation an dem das Ticket zuletzt überprüft wurde'
  },
  'ribbon instructions' => {
    'lastUpdated' => '1251857355',
    'message' => 'Anweisungen für Bänder'
  },
  'ribbon instructions help' => {
    'lastUpdated' => '1251857418',
    'message' => 'Dem Nutzer Hilfe geben, was er mit einem Band tun kann.'
  },
  'ribbonInstructions help' => {
    'lastUpdated' => '1251857452',
    'message' => 'Anweisungen für den Benutzer, was er mit einem Band tun kann.'
  },
  'ribbons' => {
    'lastUpdated' => '1251847383',
    'message' => 'Bänder'
  },
  'save approvals' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'schedule back link' => {
    'lastUpdated' => '1251857460',
    'message' => 'Zurück'
  },
  'schedule number of columns' => {
    'lastUpdated' => '1251857687',
    'message' => 'Ablaufplanorte pro Seite'
  },
  'schedule number of columns help' => {
    'lastUpdated' => '1251858776',
    'message' => 'Dies kontrolliert, wie viele Veranstaltungsorte pro Seite im Ablaufplan angezeigt werden. Hat Ihre Veranstaltung nur wenige Orte, setzen Sie diese Anzahl; für 10 oder 20 Orte definieren Sie die Hälfte oder ein Drittel der Nummer; für eine große Nummer von Orten wählen Sie den Standard.'
  },
  'schedule template' => {
    'lastUpdated' => '1251857659',
    'message' => 'Ablaufplantemplate'
  },
  'schedule template help' => {
    'lastUpdated' => '1251857546',
    'message' => 'Dieses Template wird benutzt um den Ablaufplan der Veranstaltungen anzuzeigen'
  },
  'scheduling conflict continue' => {
    'lastUpdated' => '1251857570',
    'message' => 'Hier Klicken zum Fortfahren'
  },
  'scheduling conflict message' => {
    'lastUpdated' => '1251857645',
    'message' => 'Sie haben einen Ablaufkonflikt. Bitte löschen Sie eine der folgenden Veranstaltungen aus Ihrem Einkaufswagen um fortzufahren.'
  },
  'search' => {
    'lastUpdated' => '1248388829',
    'message' => 'Suche'
  },
  'search template' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'search template description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'search template help title' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'search.data.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'search.filters.options' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'search.formFooter' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'search.formSubmit' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'seats available' => {
    'lastUpdated' => '1251666638',
    'message' => 'Verfügbare Plätze'
  },
  'seats available help' => {
    'lastUpdated' => '1251666724',
    'message' => 'Wieviele Personen können noch kaufen, bevor die Plätze ausverkauft sind?'
  },
  'seats.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'seatsAvailable' => {
    'lastUpdated' => '1257326857',
    'message' => 'Gesamtzahl an verfügbaren Sitzen für dieses Ticket'
  },
  'seatsRemaining' => {
    'lastUpdated' => '1257326881',
    'message' => 'Gesamtzahl an Sitzen die für dieses Ticket verbleiben'
  },
  'see available subevents' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'select form to edit' => {
    'lastUpdated' => '1259145073',
    'message' => 'Wählen Sie ein Formular zur Bearbeitung'
  },
  'select form to submit' => {
    'lastUpdated' => '1259145094',
    'message' => 'Wählen Sie ein Formular zur Speicherung'
  },
  'select one' => {
    'lastUpdated' => '1251666738',
    'message' => 'Eins auswählen'
  },
  'select one or more' => {
    'lastUpdated' => '1251666748',
    'message' => 'Ein weiteres auswählen'
  },
  'short title' => {
    'lastUpdated' => '1251666755',
    'message' => 'Titel'
  },
  'skip' => {
    'lastUpdated' => '1251666789',
    'message' => 'Überspringen'
  },
  'skipNotification' => {
    'lastUpdated' => '1257326926',
    'message' => 'Soll auf Benachrichtigungen zu diesem Ticket verzichtet werden?'
  },
  'skipped' => {
    'lastUpdated' => '1251666800',
    'message' => 'Übersprungen'
  },
  'sku' => {
    'lastUpdated' => '1226016507',
    'message' => 'Artikelnummer'
  },
  'sku description' => {
    'lastUpdated' => '1239658256',
    'message' => 'Eine Artikelnummer für diese Veranstaltung. Ein globaler, eindeutiger Identifizierer wird standardmäßig generiert.'
  },
  'sku template' => {
    'lastUpdated' => '1251840461',
    'message' => 'Artikelnummertemplate'
  },
  'sku template description' => {
    'lastUpdated' => '1251840535',
    'message' => 'Dieses Feld definiert, wie die Artikelnummer für jedes Produkt zusammengesetzt wird. Die Syntax ist die selbe wie in normalen Templates.'
  },
  'sold out' => {
    'lastUpdated' => '1226016495',
    'message' => 'Ausverkauft'
  },
  'startDate' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'startDate.human' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'startDateHuman' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'starts' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'starts.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'state' => {
    'lastUpdated' => '1226016484',
    'message' => 'Zustand'
  },
  'status' => {
    'lastUpdated' => '1226016467',
    'message' => 'Status'
  },
  'submission queue' => {
    'lastUpdated' => '1259619983',
    'message' => 'Warteschlange Registrierung'
  },
  'submitted location list help' => {
    'lastUpdated' => '1259620169',
    'message' => 'Geben Sie hier eine Liste der Veranstaltungsorte ein, jeweils ein Ort pro Zeile.
Diese List steht bei der Regsitrierung zur Auswahl. 
Wenn dieses Feld ausgefüllt wird, werden nur die Vernstaltungsorte zur Verfügung.'
  },
  'submitted location list label' => {
    'lastUpdated' => '1259620185',
    'message' => 'Vernstaltungsorte'
  },
  'switch to badge for' => {
    'lastUpdated' => '1251840440',
    'message' => 'Wechsel zum Namensschild von %s'
  },
  'synopsis' => {
    'lastUpdated' => '1257326939',
    'message' => 'Zusammenfassung der Ticketbeschreibung'
  },
  'tagId' => {
    'lastUpdated' => '1257326954',
    'message' => 'Tag-ID dieses Assets'
  },
  'template help title' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'templateId' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'templateId help' => {
    'lastUpdated' => '1251840409',
    'message' => 'Die Template-ID für die Hauptseite des Veranstaltungsmanagementsystems'
  },
  'ticket instructions' => {
    'lastUpdated' => '1251840268',
    'message' => 'Ticketanweisungen'
  },
  'ticket instructions help' => {
    'lastUpdated' => '1251840256',
    'message' => 'Dem Benutzer Hilfestellung geben, was er mit dem Ticket tun kann.'
  },
  'ticketDuration' => {
    'lastUpdated' => '1251840236',
    'message' => 'Wie lange dieses Ticket gilt'
  },
  'ticketEventNumber' => {
    'lastUpdated' => '1251840213',
    'message' => 'Die Veranstaltungsnummer für dieses Ticket'
  },
  'ticketInstructions help' => {
    'lastUpdated' => '1251840119',
    'message' => 'Anweisungen für den Benutzer, was er mit dem Ticket tun kann.'
  },
  'ticketLocation' => {
    'lastUpdated' => '1251840083',
    'message' => 'Wofür das Ticket ist'
  },
  'ticketMeta_[LABEL]' => {
    'lastUpdated' => '1257327035',
    'message' => 'Wert des Metatdentfeldes [LABEL]. Sonder- und Leerzeichen in [LABEL] sollen durch Unterstriche ersetzt werden'
  },
  'ticketStart' => {
    'lastUpdated' => '1251840066',
    'message' => 'Anfangsdatum des Tickets'
  },
  'ticketTitle' => {
    'lastUpdated' => '1251839988',
    'message' => 'Der Titel des Tickets, das gedruckt werden soll'
  },
  'tickets' => {
    'lastUpdated' => '1251666826',
    'message' => 'Tickets'
  },
  'tickets_loop' => {
    'lastUpdated' => '1257327073',
    'message' => 'Eine Schleife die alle verbleibenden Tickets und die dazugehörenden Daten enthält'
  },
  'time zone' => {
    'lastUpdated' => '1226016412',
    'message' => 'Zeitzone'
  },
  'time zone help' => {
    'lastUpdated' => '1240697858',
    'message' => 'Wählen Sie die Zeitzone für diese Veranstaltung'
  },
  'timezone help' => {
    'lastUpdated' => '1240697929',
    'message' => 'Die für diese Veranstaltung gültige Zeitzone'
  },
  'title' => {
    'lastUpdated' => '1164282621',
    'message' => 'Der Name für dieses Ereignis<br />'
  },
  'title.url' => {
    'lastUpdated' => '1251839966',
    'message' => 'URL um eine Liste der Veranstaltungen anzuzeigen, die diese Veranstaltung enthält.'
  },
  'tmplLoop errorLoop' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar approved' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar error' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar event' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar isError' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar price' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar sku' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar sku template' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar weight' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'token instructions' => {
    'lastUpdated' => '1251839911',
    'message' => 'Gutscheinanweisungen'
  },
  'token instructions help' => {
    'lastUpdated' => '1251839901',
    'message' => 'Dem Nutzer Hilfestellung geben, was er mit dem Gutschein anfangen kann.'
  },
  'tokenInstructions help' => {
    'lastUpdated' => '1251839869',
    'message' => 'Anweisungen für den Nutzer, was er mit dem Gutschein tun kann.'
  },
  'tokens' => {
    'lastUpdated' => '1251839841',
    'message' => 'Gutscheine'
  },
  'transactionId' => {
    'lastUpdated' => '1251839829',
    'message' => 'Der eindeutige Bezeichner für diese Transaktion in der Datenbank.'
  },
  'transactionItemId' => {
    'lastUpdated' => '1251839800',
    'message' => 'Der eindeutige Identifier für das Transaktionsitem dieses Namensschildes. Nützlich für internes Tracking.'
  },
  'type label here' => {
    'lastUpdated' => '1251839737',
    'message' => 'Hier Label eingeben'
  },
  'type name here' => {
    'lastUpdated' => '1251839725',
    'message' => 'Hier Name eingeben'
  },
  'url' => {
    'lastUpdated' => '1251839711',
    'message' => 'URL zu diesem Veranstaltungsmanagementsystems'
  },
  'usePackedHeadTags' => {
    'lastUpdated' => '1257327103',
    'message' => 'Sollen gepackte Kopfdaten für dieses Ticket genutzt werden?'
  },
  'user' => {
    'lastUpdated' => '1226016338',
    'message' => 'Nutzer'
  },
  'userId' => {
    'lastUpdated' => '1251839677',
    'message' => 'Benutzer-ID des Namensschildbenutzers'
  },
  'view badge template' => {
    'lastUpdated' => '1251839646',
    'message' => 'Namensschildtemplate'
  },
  'view badge template help' => {
    'lastUpdated' => '1251839633',
    'message' => 'Das Template, das das Formular zur Eingabe der Namensschildinformationen anzeigt'
  },
  'view badges' => {
    'lastUpdated' => '1251839458',
    'message' => 'Namensschilder ansehen'
  },
  'view my submissions' => {
    'lastUpdated' => '1259620006',
    'message' => 'Meine Registrierungen'
  },
  'view purchase' => {
    'lastUpdated' => '1251666340',
    'message' => 'Einkauf ansehen'
  },
  'view purchase template' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'view purchase template description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'view purchase template help title' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'view schedule' => {
    'lastUpdated' => '1251666313',
    'message' => 'Plan'
  },
  'view submission queue' => {
    'lastUpdated' => '1259620027',
    'message' => 'Warteschlange Registrierungen'
  },
  'view tickets' => {
    'lastUpdated' => '1251666295',
    'message' => 'Ticket ansehen'
  },
  'viewCartUrl' => {
    'lastUpdated' => '1251666282',
    'message' => 'URL zur Einkaufswagen-Ansicht'
  },
  'viewEventsUrl' => {
    'lastUpdated' => '1251666251',
    'message' => 'URL zur Betrachtung des Tickets'
  },
  'viewPurchaseTitle' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'weight' => {
    'lastUpdated' => '1251666233',
    'message' => 'Gewicht'
  },
  'weight description' => {
    'lastUpdated' => '1251666222',
    'message' => 'Jedes Gewicht kann diesem Ereignis zugeordnet werden'
  },
  'what about duplicates' => {
    'lastUpdated' => '1251666177',
    'message' => 'Was ist mit Dubletten?'
  },
  'which badge' => {
    'lastUpdated' => '1251839444',
    'message' => 'Welches Namensschild'
  },
  'whichTab' => {
    'lastUpdated' => '1251839422',
    'message' => 'Der aktuelle Karteireiter in der Namensschildbilderseite'
  },
  'yes' => {
    'lastUpdated' => '1217254700',
    'message' => 'ja'
  },
  'you' => {
    'lastUpdated' => '1226016282',
    'message' => 'Sie'
  },
  'you do not have any events to display' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'you do not have any metadata fields to display' => {
    'lastUpdated' => '1251666071',
    'message' => 'Es existieren keine Metadatenfelder zum Anzeigen'
  },
  'zip code' => {
    'lastUpdated' => '1226016298',
    'message' => 'Postleitzahl'
  },
  'zipcode' => {
    'lastUpdated' => '1226016320',
    'message' => 'Die Postleitzahl des Nutzers'
  }
}
;

1;
